@@ -466,7 +466,7 @@ class Proxy(object):
                         return msg
                     data = serializer.deserializeData(msg.data, compressed=msg.flags & message.FLAGS_COMPRESSED)
                     if msg.flags & message.FLAGS_ITEMSTREAMRESULT:
-                        streamId = msg.annotations.get("STRM", b"").decode()
+                        streamId = bytes(msg.annotations.get("STRM", b"")).decode()
                         if not streamId:
                             raise errors.ProtocolError("result of call is an iterator, but the server is not configured to allow streaming")
                         return _StreamResultIterator(streamId, self)
@@ -1113,8 +1113,8 @@ class Daemon(object):
                 host = config.HOST
             if nathost is None:
                 nathost = config.NATHOST
-            if natport is None:
-                natport = config.NATPORT or None
+            if natport is None and nathost is not None:
+                natport = config.NATPORT
             if nathost and unixsocket:
                 raise ValueError("cannot use nathost together with unixsocket")
             if (nathost is None) ^ (natport is None):
